@@ -74,6 +74,10 @@ class JsonHtmlConverter(BaseConverter):
             libdoc.keywords, libdoc.doc, libdoc.doc_format
         )
         data = htmlwriter.JsonConverter(formatter).convert(libdoc)
+
+        for keyword in data["keywords"]:
+            keyword["shortdoc"] = formatter.html(keyword["shortdoc"])
+
         with open(output, "w") as fd:
             json.dump(data, fd, indent=4)
 
